package
Version:
v1.0.4
Opens a new window with list of versions in this module.
Published: May 13, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Response struct {
Ok bool `json:"ok,omitempty"`
Result interface{} `json:"result,omitempty"`
Description string `json:"description,omitempty"`
}
type ResponseParameters struct {
MigrateToChatId int64 `json:"migrate_to_chat_id,omitempty"`
RetryAfter int64 `retry_after:"result,omitempty"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.